@@ -1,5 +1,3 @@
-context("wflow_publish")
-
 # Setup ------------------------------------------------------------------------
 
 library("git2r")
@@ -206,6 +204,7 @@ test_that("wflow_publish deletes cache when delete_cache = TRUE", {
 
   skip_on_cran()
   skip_on_os("windows") # Avoid errors due to long filenames
+  skip_if_not_installed("codetools")
 
   # Build a file that has cached chunks
   file_w_cache <- file.path(s$analysis, "cache.Rmd")
